@@ -1,7 +1,9 @@
 from accim.sim import accis
 accis.addAccis(ScriptType='ex_ac',
-               Outputs='standard',
-               EnergyPlus_version='ep95',
+               Output_keep_existing=False,
+               Output_type='standard',
+               Output_freqs=['hourly'],
+               EnergyPlus_version='9.5',
                TempCtrl='temp',
                ComfStand=[1],
                CAT=[2],
